@@ -31,7 +31,7 @@ class App(object):
         self.app = FastAPI()
         self.verbose = verbose
 
-    def run(self, app=None, host="0.0.0.0", port=8000, workers=1, access_log=True, debug=True, reload=True, **kwargs):
+    def run(self, app=None, host="0.0.0.0", port=8000, workers=1, access_log=True, debug=False, reload=False, **kwargs):
         """
 
         :param app:   app字符串可开启热更新
@@ -102,6 +102,15 @@ class App(object):
 
         return output
 
+    def app_file_name(self, file):
+        """
+        file = __file__
+        """
+        print(file)
+        _ = file.split('/')[-1].split('.')[0]
+        return f"{_}:app"
+
+
 
 if __name__ == '__main__':
     import uvicorn
@@ -111,4 +120,4 @@ if __name__ == '__main__':
     app.add_route('/post', lambda **kwargs: kwargs, method="POST", result_key="PostResult")
 
     app.run(port=9000, debug=False, reload=False)
-    # app_.run(f"{main_file}:app", port=9000)
+    # app.run(f"{app.app_file_name(__file__)}", port=9000, debug=False, reload=False)
